﻿var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var BaseEditor = (function (_super) {
    __extends(BaseEditor, _super);
    function BaseEditor(id, document) {
        var _this = _super.call(this, EditorProObjectTypes.Editor, id) || this;
        _this._mode = null;
        _this._systemEditor = null;
        _this._document = document;
        return _this;
    }
    Object.defineProperty(BaseEditor.prototype, "SystemEditor", {
        get: function () {
            if (this._systemEditor == null) {
                this._systemEditor = this._document.Editors.getValue(this.Id);
            }
            return this._systemEditor;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseEditor.prototype, "Sheets", {
        get: function () {
            return this.SystemEditor.Sheets;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseEditor.prototype, "Document", {
        get: function () {
            return this._document;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseEditor.prototype, "Mode", {
        get: function () {
            return this._mode == null ? +this.SystemEditor.Mode : this._mode;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseEditor.prototype, "IsPreviewMode", {
        get: function () {
            return this._mode === EditorShowMode.Preview;
        },
        enumerable: true,
        configurable: true
    });
    BaseEditor.prototype.ResetMode = function () {
        this._mode = null;
    };
    BaseEditor.prototype.CommonGetIsReadonlyEventHandler = function (sheetId, tableId, fieldId, isReadonly) {
        if (this.IsPreviewMode) {
            return true;
        }
        else {
            return isReadonly;
        }
    };
    BaseEditor.prototype.CommonGetIsVisibleEventHandler = function (sheetId, tableId, fieldId, isVisible) {
        if (this.IsPreviewMode) {
            return true;
        }
        else {
            return isVisible;
        }
    };
    BaseEditor.prototype.CommonGetButtonVisible = function (tableId, fieldId, buttonId, isVisible) {
        switch (this.Mode) {
            case EditorShowMode.Preview:
                return buttonId.indexOf("PreviewButton") > -1;
            default:
                return isVisible;
        }
    };
    BaseEditor.prototype.GetMainButtonVisible = function (tableId, fieldId, buttonId, isVisible) {
        switch (buttonId) {
            case ClientButton.EditorOkButton.Id:
                return !this.IsPreviewMode;
            default:
                return true;
        }
    };
    BaseEditor.prototype.GetMainButtonCaption = function (tableId, fieldId, buttonId, caption) {
        switch (buttonId) {
            case ClientButton.EditorCancelButton.Id:
                return this.IsPreviewMode ? "OK" : ClientButton.EditorCancelButton.DefaultCaption;
            default:
                return caption;
        }
    };
    BaseEditor.prototype.Show = function (mode) {
        this._mode = mode;
        var result;
        switch (mode) {
            case EditorShowMode.Create:
                result = this.SystemEditor.Show(EditorMode.Create);
                break;
            case EditorShowMode.Edit:
                result = this.SystemEditor.Show(EditorMode.Edit);
                break;
            default:
                result = this.SystemEditor.Show();
        }
        this.ResetMode();
        return result;
    };
    return BaseEditor;
}(BaseObject));
var SprElementEditor = (function (_super) {
    __extends(SprElementEditor, _super);
    function SprElementEditor(source, document) {
        var _this = _super.call(this, source.Id, document) || this;
        _this._source = source;
        return _this;
    }
    Object.defineProperty(SprElementEditor.prototype, "SourceTable", {
        get: function () {
            return this._source;
        },
        enumerable: true,
        configurable: true
    });
    SprElementEditor.prototype.CommonGetIsVisibleEventHandler = function (sheetId, tableId, fieldId, isVisible) {
        switch (this.Mode) {
            case EditorShowMode.Preview:
                var fieldIds = fieldId.split(";");
                var flag = false;
                var table = this.Document.Tables.getValue(tableId);
                for (var i = 0, len = fieldIds.length; i < len; i++) {
                    flag = flag || table.GetFieldValue(fieldIds[i]) != null;
                }
                return flag;
        }
        return _super.prototype.CommonGetIsVisibleEventHandler.call(this, sheetId, tableId, fieldId, isVisible);
    };
    SprElementEditor.prototype.IsReadOnly = function () {
        return this.Mode === EditorShowMode.Edit;
    };
    SprElementEditor.prototype.CanCloseEventHandler = function (modRes) {
        if (modRes === MessageResults.Ok) {
            this.SourceTable.DoTableChange();
        }
        return true;
    };
    return SprElementEditor;
}(BaseEditor));
var VersionElementEditor = (function (_super) {
    __extends(VersionElementEditor, _super);
    function VersionElementEditor() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VersionElementEditor.prototype.CanShowStartDate = function () {
        return this.Mode === EditorShowMode.Create || this.Mode === EditorShowMode.Preview;
    };
    VersionElementEditor.prototype.CommonGetIsVisibleEventHandler = function (sheetId, tableId, fieldId, isVisible) {
        if (fieldId === this.SourceTable.StartDate.Id) {
            return isVisible;
        }
        return _super.prototype.CommonGetIsVisibleEventHandler.call(this, sheetId, tableId, fieldId, isVisible);
    };
    return VersionElementEditor;
}(SprElementEditor));
var TofkMinfinEditor = (function (_super) {
    __extends(TofkMinfinEditor, _super);
    function TofkMinfinEditor(source, document) {
        var _this = _super.call(this, source, document) || this;
        _this._previewTable = null;
        _this._previewId = _this.SourceTable.Id + "Preview";
        return _this;
    }
    Object.defineProperty(TofkMinfinEditor.prototype, "PreviewTable", {
        get: function () {
            if (this._previewTable == null) {
                this._previewTable = new TofkTable(this._previewId);
            }
            return this._previewTable;
        },
        enumerable: true,
        configurable: true
    });
    TofkMinfinEditor.prototype.Show = function (mode) {
        this.PreviewTable.DeleteAllRow();
        this.SourceTable.CopyRow(this.PreviewTable);
        return _super.prototype.Show.call(this, mode);
    };
    return TofkMinfinEditor;
}(SprElementEditor));
var SprElementsListEditor = (function (_super) {
    __extends(SprElementsListEditor, _super);
    function SprElementsListEditor(source, document) {
        var _this = _super.call(this, source.Id + "ListEditor", document) || this;
        _this._srcTable = source.SourceTable;
        _this._srcEditor = source;
        _this._sheetId = source.Id + "ListSheet";
        return _this;
    }
    Object.defineProperty(SprElementsListEditor.prototype, "SourceTable", {
        get: function () {
            return this._srcTable;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SprElementsListEditor.prototype, "SourceEditor", {
        get: function () {
            return this._srcEditor;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SprElementsListEditor.prototype, "SrcKey", {
        get: function () {
            return this.Sheet.Table.GetKeyBySourceTable(this._srcTable);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SprElementsListEditor.prototype, "Sheet", {
        get: function () {
            return this.Sheets.getValue(this._sheetId);
        },
        enumerable: true,
        configurable: true
    });
    SprElementsListEditor.prototype.PreviewMenuItemClickEventHandler = function () {
        var srcKey = this.SrcKey;
        if (srcKey && this._srcEditor.SourceTable.LocateByKeys(srcKey)) {
            this._srcEditor.Show(EditorShowMode.Preview);
        }
    };
    SprElementsListEditor.prototype.IsRecordLocated = function () {
        var srcKey = this.SrcKey;
        return srcKey != null;
    };
    return SprElementsListEditor;
}(BaseEditor));
var SprVersionElementsListEditor = (function (_super) {
    __extends(SprVersionElementsListEditor, _super);
    function SprVersionElementsListEditor() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SprVersionElementsListEditor.prototype.UpdateReferences = function (registryTable) {
        registryTable.UpdateAllDraftRequisites();
    };
    SprVersionElementsListEditor.prototype.AddVersionMenuItemClickEventHandler = function () {
        var srcKey = this.SrcKey;
        if (srcKey) {
            this.SourceTable.CreateNewVersion(srcKey);
            if (this.SourceEditor.Show(EditorShowMode.Edit)) {
                this.UpdateReferences(this.Document.BankGuaranteesTable);
                this.UpdateReferences(this.Document.BankGuaranteesRequestTable);
                this.Sheet.Refresh();
            }
            else {
                this.SourceTable.DeleteRow();
            }
        }
    };
    SprVersionElementsListEditor.prototype.AddRequisiteMenuItemClickEventHandler = function () {
        if (this.SourceEditor.Show(EditorShowMode.Create)) {
            this.Sheet.Refresh();
        }
    };
    SprVersionElementsListEditor.prototype.CanAddRequisites = function () {
        return this.SourceTable.RowCount === 0;
    };
    return SprVersionElementsListEditor;
}(SprElementsListEditor));
var RegistryElementEditor = (function (_super) {
    __extends(RegistryElementEditor, _super);
    function RegistryElementEditor(source, document) {
        var _this = _super.call(this, source.Id + "Editor", document) || this;
        _this._source = source;
        return _this;
    }
    Object.defineProperty(RegistryElementEditor.prototype, "SourceTable", {
        get: function () {
            return this._source;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RegistryElementEditor.prototype, "LegalEntityContainer", {
        get: function () {
            if (this._legalEntityContainer == null) {
                this._legalEntityContainer = this.InitLegalEntityContainer();
            }
            return this._legalEntityContainer;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RegistryElementEditor.prototype, "IndividBusinessmanContainer", {
        get: function () {
            if (this._individBusinessmanContainer == null) {
                this._individBusinessmanContainer = this.InitIndividBusinessmanContainer();
            }
            return this._individBusinessmanContainer;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RegistryElementEditor.prototype, "ForeignCitizenContainer", {
        get: function () {
            if (this._foreignCitizenContainer == null) {
                this._foreignCitizenContainer = this.InitForeignCitizenContainer();
            }
            return this._foreignCitizenContainer;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RegistryElementEditor.prototype, "ForeignLegalContainer", {
        get: function () {
            if (this._foreignLegalContainer == null) {
                this._foreignLegalContainer = this.InitForeignLegalContainer();
            }
            return this._foreignLegalContainer;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RegistryElementEditor.prototype, "CustomerContainer", {
        get: function () {
            if (this._customerContainer == null) {
                this._customerContainer = this.InitCustomerContainer();
            }
            return this._customerContainer;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RegistryElementEditor.prototype, "BankContainer", {
        get: function () {
            if (this._bankContainer == null) {
                this._bankContainer = this.Document.BankContainer;
            }
            return this._bankContainer;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RegistryElementEditor.prototype, "TofkContainer", {
        get: function () {
            if (this._tofkContainer == null) {
                this._tofkContainer = this.Document.TofkContainer;
            }
            return this._tofkContainer;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RegistryElementEditor.prototype, "TofkMinfinContainer", {
        get: function () {
            if (this._tofkMinfinContainer == null) {
                this._tofkMinfinContainer = this.Document.TofkMinfinContainer;
            }
            return this._tofkMinfinContainer;
        },
        enumerable: true,
        configurable: true
    });
    RegistryElementEditor.prototype.IsReadOnly = function () {
        var status = this._source.StatusField.ForeignKey.Value;
        return !(status === ObasHelper.DraftStatusKey || status === ObasHelper.ReadyStatusKey);
    };
    RegistryElementEditor.prototype.IsDraft = function () {
        return this._source.IsDraft;
    };
    RegistryElementEditor.prototype.CanShowUserTofk = function () {
        return this._source.IsUserTofk.Value;
    };
    RegistryElementEditor.prototype.CanShowMinfinTofk = function () {
        return !this._source.IsUserTofk.Value;
    };
    RegistryElementEditor.prototype.ShowProvider = function (providerType) {
        return this._source.ProviderType === providerType;
    };
    RegistryElementEditor.prototype.PreviewSprElement = function (container, fieldId) {
        var key = this.SourceTable.GetFieldValue(fieldId);
        var editor = container.Editor;
        if (key != null && editor.SourceTable.LocateByKeys(key)) {
            editor.Show(EditorShowMode.Preview);
        }
        else {
            Client.ShowMessage("Внимание", "Данный элемент не доступен", MessageIcons.Warning);
        }
    };
    RegistryElementEditor.prototype.CommonBankGetButtonVisible = function (tableId, fieldId, buttonId, isVisible) {
        if (buttonId === ClientButton.AddElementToListButton.Id && this.Mode !== EditorShowMode.Preview) {
            return !this.IsBankReadOnly();
        }
        else {
            return this.CommonGetButtonVisible(tableId, fieldId, buttonId, isVisible);
        }
    };
    RegistryElementEditor.prototype.IsBankReadOnly = function () {
        return this.BankContainer.Table.RowCount !== 0;
    };
    RegistryElementEditor.prototype.IsDraftNotRequired = function () {
        return !this.IsDraft();
    };
    RegistryElementEditor.prototype.CanShowLegalEntity = function () {
        return this.ShowProvider(ProviderTypes.LegalEntity);
    };
    RegistryElementEditor.prototype.CanShowIndividualBusinessman = function () {
        return this.ShowProvider(ProviderTypes.IndividualBusinessman);
    };
    RegistryElementEditor.prototype.CanShowForeignCitizen = function () {
        return this.ShowProvider(ProviderTypes.ForeignCitizen);
    };
    RegistryElementEditor.prototype.CanShowForeignLegalEntity = function () {
        return this.ShowProvider(ProviderTypes.ForeignLegalEntity);
    };
    RegistryElementEditor.prototype.IsRequiredLegalEntity = function () {
        return (this.IsDraftNotRequired() &&
            this.CanShowLegalEntity());
    };
    RegistryElementEditor.prototype.IsRequiredIndividualBusinessman = function () {
        return (this.IsDraftNotRequired() &&
            this.CanShowIndividualBusinessman());
    };
    RegistryElementEditor.prototype.IsRequiredForeignCitizen = function () {
        return (this.IsDraftNotRequired() &&
            this.CanShowForeignCitizen());
    };
    RegistryElementEditor.prototype.IsRequiredForeignLegalEntity = function () {
        return (this.IsDraftNotRequired() &&
            this.CanShowForeignLegalEntity());
    };
    RegistryElementEditor.prototype.IsRequiredUserTofk = function () {
        return this.CanShowUserTofk() && this.IsDraftNotRequired();
    };
    RegistryElementEditor.prototype.IsRequiredMinfinTofk = function () {
        return this.CanShowMinfinTofk() && this.IsDraftNotRequired();
    };
    RegistryElementEditor.prototype.CommonGetIsVisibleEventHandler = function (sheetId, tableId, fieldId, isVisible) {
        if (this.IsPreviewMode) {
            switch (fieldId) {
                case this.SourceTable.TofkKey.Id:
                case this.SourceTable.TofkMinfinKey.Id:
                case this.SourceTable.LegalEntityProvider.Id:
                case this.SourceTable.IndividualProvider.Id:
                case this.SourceTable.ForeignCitizenProvider.Id:
                case this.SourceTable.ForeignLegalProvider.Id:
                    return isVisible;
                default:
                    return true;
            }
        }
        else {
            return isVisible;
        }
    };
    RegistryElementEditor.prototype.FilterVersionElement = function (sprTable) {
        var infoDate = +this.SourceTable.CreateDate;
        return (this.SourceTable.IsArched || ((+sprTable.StartDate.Value <= infoDate &&
            (sprTable.EndDate.Value == null || +sprTable.EndDate.Value >= infoDate)) ||
            (sprTable.EndDate.Value == null && this.SourceTable.CreateDate == null)));
    };
    RegistryElementEditor.prototype.FilterTaxVersionElement = function (sprTable) {
        var infoDate = +(this.SourceTable.CreateDate || new Date());
        return (this.FilterVersionElement(sprTable) &&
            +sprTable.TaxRegDate.Value <= infoDate);
    };
    RegistryElementEditor.prototype.FilterBanks = function () {
        return this.FilterTaxVersionElement(TableCollection.BankTable);
    };
    RegistryElementEditor.prototype.FilterLegalEntities = function () {
        return this.FilterTaxVersionElement(TableCollection.LegalEntityProviderTable);
    };
    RegistryElementEditor.prototype.FilterIndividualBusinessmens = function () {
        return this.FilterTaxVersionElement(TableCollection.IndividualBusinessmanTable);
    };
    RegistryElementEditor.prototype.FilterForeignCitizens = function () {
        return this.FilterTaxVersionElement(TableCollection.ForeignCitizenTable);
    };
    RegistryElementEditor.prototype.FilterForeignLegalEntities = function () {
        return this.FilterTaxVersionElement(TableCollection.ForeignLegalEntityProviderTable);
    };
    RegistryElementEditor.prototype.FilterCustomers = function () {
        return this.FilterTaxVersionElement(TableCollection.CustomerTable);
    };
    RegistryElementEditor.prototype.FilterTofks = function () {
        return this.FilterVersionElement(TableCollection.TofkTable);
    };
    RegistryElementEditor.prototype.BankPreviewButtonClick = function (tableId, fieldId, buttonId) {
        this.PreviewSprElement(this.BankContainer, fieldId);
    };
    RegistryElementEditor.prototype.LegalEntityPreviewButtonClick = function (tableId, fieldId, buttonId) {
        this.PreviewSprElement(this.LegalEntityContainer, fieldId);
    };
    RegistryElementEditor.prototype.IndividBusinessmanPreviewButtonClick = function (tableId, fieldId, buttonId) {
        this.PreviewSprElement(this.IndividBusinessmanContainer, fieldId);
    };
    RegistryElementEditor.prototype.ForeignCitizenPreviewButtonClick = function (tableId, fieldId, buttonId) {
        this.PreviewSprElement(this.ForeignCitizenContainer, fieldId);
    };
    RegistryElementEditor.prototype.ForeignLegalPreviewButtonClick = function (tableId, fieldId, buttonId) {
        this.PreviewSprElement(this.ForeignLegalContainer, fieldId);
    };
    RegistryElementEditor.prototype.CustomerPreviewButtonClick = function (tableId, fieldId, buttonId) {
        this.PreviewSprElement(this.CustomerContainer, fieldId);
    };
    RegistryElementEditor.prototype.TofkPreviewButtonClick = function (tableId, fieldId, buttonId) {
        this.PreviewSprElement(this.TofkContainer, fieldId);
    };
    RegistryElementEditor.prototype.TofkMinfinPreviewButtonClick = function (tableId, fieldId, buttonId) {
        this.PreviewSprElement(this.TofkMinfinContainer, fieldId);
    };
    RegistryElementEditor.prototype.PreviewButtonEnabled = function (tableId, fieldId) {
        return this.SourceTable.GetFieldValue(fieldId) != null;
    };
    return RegistryElementEditor;
}(BaseEditor));
var InfoRegistryElementEditor = (function (_super) {
    __extends(InfoRegistryElementEditor, _super);
    function InfoRegistryElementEditor(document) {
        return _super.call(this, document.BankGuaranteesTable, document) || this;
    }
    InfoRegistryElementEditor.prototype.IsReceived = function () {
        return this.SourceTable.Status === DataStatuses.Received;
    };
    InfoRegistryElementEditor.prototype.IsDenied = function () {
        return this.SourceTable.Status === DataStatuses.Denied;
    };
    InfoRegistryElementEditor.prototype.IsIncluded = function () {
        return this.SourceTable.Status === DataStatuses.Included;
    };
    InfoRegistryElementEditor.prototype.IsRequiredUserTofk = function () {
        return this.CanShowUserTofk() && this.IsReceived();
    };
    InfoRegistryElementEditor.prototype.IsRequiredMinfinTofk = function () {
        return this.CanShowMinfinTofk() && this.IsReceived();
    };
    InfoRegistryElementEditor.prototype.CanShowUserTofk = function () {
        return _super.prototype.CanShowUserTofk.call(this) &&
            (this.IsReceived() || this.IsPreviewMode);
    };
    InfoRegistryElementEditor.prototype.CanShowMinfinTofk = function () {
        return _super.prototype.CanShowMinfinTofk.call(this) &&
            (this.IsReceived() || this.IsPreviewMode);
    };
    InfoRegistryElementEditor.prototype.DocsLoadEventHandler = function (tableId) {
        return this.SourceTable.Docs.BankGuaranteesKey.Value === this.SourceTable.RecordKey.Value;
    };
    InfoRegistryElementEditor.prototype.IsReadOnlyDocs = function () {
        return !this.IsReadOnly() || this.IsPreviewMode;
    };
    InfoRegistryElementEditor.prototype.CanShowUsd = function () {
        return !OkvSprTable.IsRuble(this.SourceTable.Okv.Code);
    };
    InfoRegistryElementEditor.prototype.IsRequiredUsd = function () {
        return this.CanShowUsd() && this.IsDraftNotRequired();
    };
    InfoRegistryElementEditor.prototype.IsReadOnlyRub = function () {
        return this.CanShowUsd();
    };
    InfoRegistryElementEditor.prototype.FilterStatuses = function () {
        var status = TableCollection.DataStatusesSprTable.Status;
        switch (this.SourceTable.Status) {
            case DataStatuses.Send:
                return (status === DataStatuses.Send ||
                    status === DataStatuses.Received);
            case DataStatuses.Draft:
                return (status === DataStatuses.Draft ||
                    status === DataStatuses.Ready);
            case DataStatuses.Ready:
                return (status === DataStatuses.Draft ||
                    status === DataStatuses.Ready ||
                    status === DataStatuses.Send);
            case DataStatuses.Received:
                return !(status === DataStatuses.Draft ||
                    status === DataStatuses.Ready);
            case DataStatuses.Denied:
                return (status === DataStatuses.Received ||
                    status === DataStatuses.Denied);
            case DataStatuses.Included:
                return (status === DataStatuses.Received ||
                    status === DataStatuses.Included);
            default:
                return true;
        }
    };
    InfoRegistryElementEditor.prototype.InitLegalEntityContainer = function () {
        return this.Document.LegalEntityContainer;
    };
    InfoRegistryElementEditor.prototype.InitIndividBusinessmanContainer = function () {
        return this.Document.IndividualBusinessmanContainer;
    };
    InfoRegistryElementEditor.prototype.InitForeignCitizenContainer = function () {
        return this.Document.ForeignCitizenContainer;
    };
    InfoRegistryElementEditor.prototype.InitForeignLegalContainer = function () {
        return this.Document.ForeignLegalContainer;
    };
    InfoRegistryElementEditor.prototype.InitCustomerContainer = function () {
        return this.Document.CustomerContainer;
    };
    return InfoRegistryElementEditor;
}(RegistryElementEditor));
var RequestRegistryElementEditor = (function (_super) {
    __extends(RequestRegistryElementEditor, _super);
    function RequestRegistryElementEditor(document) {
        return _super.call(this, document.BankGuaranteesRequestTable, document) || this;
    }
    Object.defineProperty(RequestRegistryElementEditor.prototype, "ExcludedFields", {
        get: function () {
            if (this._excludedFields == null) {
                this._excludedFields = [this.SourceTable.DeclarerKey.Id,
                    this.SourceTable.BankKey.Id,
                    this.SourceTable.DeclarerEmployee.Post.Id,
                    this.SourceTable.DeclarerEmployee.FullName.Id,
                    this.SourceTable.BankEmployee.Post.Id,
                    this.SourceTable.BankEmployee.FullName.Id];
            }
            return this._excludedFields;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RequestRegistryElementEditor.prototype, "DeclarerContainer", {
        get: function () {
            if (this._declarerContainer == null) {
                this._declarerContainer = this.Document.DeclarerContainer;
            }
            return this._declarerContainer;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RequestRegistryElementEditor.prototype, "BankShortContainer", {
        get: function () {
            if (this._bankShortContainer == null) {
                this._bankShortContainer = this.Document.BankShortContainer;
            }
            return this._bankShortContainer;
        },
        enumerable: true,
        configurable: true
    });
    RequestRegistryElementEditor.prototype.IsReceived = function () {
        return this.SourceTable.Status === RequestStatuses.Received;
    };
    RequestRegistryElementEditor.prototype.IsSend = function () {
        return this.SourceTable.Status === RequestStatuses.Send;
    };
    RequestRegistryElementEditor.prototype.CanShowBank = function () {
        return this.Document.InterfaceRules.IsFullAssembly();
    };
    RequestRegistryElementEditor.prototype.CanShowDeclarer = function () {
        return this.Document.InterfaceRules.IsShortAssembly();
    };
    RequestRegistryElementEditor.prototype.IsRequiredBank = function () {
        return this.CanShowBank() && this.IsDraftNotRequired();
    };
    RequestRegistryElementEditor.prototype.IsRequiredDeclarer = function () {
        return this.CanShowDeclarer() && this.IsDraftNotRequired();
    };
    RequestRegistryElementEditor.prototype.FilterStatuses = function () {
        var status = TableCollection.RequestStatusesSprTable.Status;
        switch (this.SourceTable.Status) {
            case RequestStatuses.Received:
            case RequestStatuses.Send:
                return (status === RequestStatuses.Send || status === RequestStatuses.Received);
            case RequestStatuses.Draft:
                return (status === RequestStatuses.Draft || status === RequestStatuses.Ready);
            case RequestStatuses.Ready:
                return (status !== RequestStatuses.Received);
            default:
                return true;
        }
    };
    RequestRegistryElementEditor.prototype.DeclarerPreviewButtonClick = function (tableId, fieldId, buttonId) {
        this.PreviewSprElement(this.DeclarerContainer, fieldId);
    };
    RequestRegistryElementEditor.prototype.BankDetailsShortPreviewButtonClick = function (tableId, fieldId, buttonId) {
        this.PreviewSprElement(this.BankShortContainer, fieldId);
    };
    RequestRegistryElementEditor.prototype.FilterDeclarers = function () {
        return this.FilterTaxVersionElement(TableCollection.DeclarerTable);
    };
    RequestRegistryElementEditor.prototype.InitLegalEntityContainer = function () {
        return this.Document.LegalEntityShortContainer;
    };
    RequestRegistryElementEditor.prototype.InitIndividBusinessmanContainer = function () {
        return this.Document.IndividualBusinessmanShortContainer;
    };
    RequestRegistryElementEditor.prototype.InitForeignCitizenContainer = function () {
        return this.Document.ForeignCitizenShortContainer;
    };
    RequestRegistryElementEditor.prototype.InitForeignLegalContainer = function () {
        return this.Document.ForeignLegalShortContainer;
    };
    RequestRegistryElementEditor.prototype.InitCustomerContainer = function () {
        return this.Document.CustomerShortContainer;
    };
    RequestRegistryElementEditor.prototype.CommonGetIsVisibleEventHandler = function (sheetId, tableId, fieldId, isVisible) {
        if (this.IsPreviewMode) {
            for (var i = 0, len = this.ExcludedFields.length; i < len; i++) {
                if (fieldId.indexOf(this.ExcludedFields[i]) > -1) {
                    return isVisible;
                }
            }
            return _super.prototype.CommonGetIsVisibleEventHandler.call(this, sheetId, tableId, fieldId, isVisible);
        }
        else {
            return isVisible;
        }
    };
    RequestRegistryElementEditor.prototype.CommonDeclarerGetButtonVisible = function (tableId, fieldId, buttonId, isVisible) {
        if (buttonId === ClientButton.AddElementToListButton.Id && this.Mode !== EditorShowMode.Preview) {
            return !this.IsDeclarerReadOnly();
        }
        else {
            return this.CommonGetButtonVisible(tableId, fieldId, buttonId, isVisible);
        }
    };
    RequestRegistryElementEditor.prototype.IsDeclarerReadOnly = function () {
        return this.DeclarerContainer.Table.RowCount !== 0;
    };
    return RequestRegistryElementEditor;
}(RegistryElementEditor));
