﻿var ObasHelper = (function () {
    function ObasHelper() {
    }
    Object.defineProperty(ObasHelper, "DraftStatusKey", {
        get: function () {
            return this._definedKeys.DraftStatus;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ObasHelper, "ReadyStatusKey", {
        get: function () {
            return this._definedKeys.ReadyStatus;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ObasHelper, "MonthName", {
        get: function () {
            return ObasHelper._monthNames;
        },
        enumerable: true,
        configurable: true
    });
    ObasHelper.GetTrue = function () {
        return true;
    };
    ObasHelper.GetFalse = function () {
        return false;
    };
    ObasHelper.ConvertToString = function (param, format) {
        if (format != null && !isNaN(format)) {
            format = parseInt(format, 10);
        }
        if (param == null) {
            return "";
        }
        else if (param instanceof Date) {
            return ObasHelper.ConvertDateToString(param, format);
        }
        else if (typeof param === "boolean" && format == null) {
            return param ? "Да" : "Нет";
        }
        else if (typeof param === "number" && format != null) {
            var result = param.toString();
            if (format != null) {
                result = ObasHelper.ModRound(param, format).toFixed(format).replace(/(\d)(?=(\d{3})+\.)/g, "$1 ");
            }
            return result.replace(/\./g, ",");
        }
        return param.toString();
    };
    ObasHelper.NullifyTime = function (date) {
        if (date) {
            date.setHours(0, 0, 0, 0);
        }
        return date;
    };
    ObasHelper.ModRound = function (value, precision) {
        var prec = Math.pow(10, precision);
        var coef = value < 0 ? -1 : 1;
        return coef * Math.round(Math.abs(value) * prec) / prec;
    };
    ObasHelper.ConvertDateToString = function (date, format) {
        if (format === void 0) { format = DateFormat.Short; }
        switch (format) {
            case DateFormat.OnlyTime:
                {
                    var result = [];
                    result.push(ObasHelper.FillWithCharacter(date.getHours(), 2));
                    result.push(ObasHelper.FillWithCharacter(date.getMinutes(), 2));
                    result.push(ObasHelper.FillWithCharacter(date.getSeconds(), 2));
                    return result.join(":");
                }
            case DateFormat.Json:
                {
                    return date.toJSON();
                }
            case DateFormat.Long:
            case DateFormat.Middle:
                {
                    var result = "\" " + date.getDate() + " \" " + ObasHelper.MonthName[date.getMonth()].GenName + " " + date.getFullYear() + " г.";
                    if (format === DateFormat.Long) {
                        result = "от " + result;
                    }
                    return result;
                }
            default:
                {
                    var result = [];
                    result.push(ObasHelper.FillWithCharacter(date.getDate(), 2));
                    result.push(ObasHelper.FillWithCharacter(date.getMonth() + 1, 2));
                    result.push(date.getFullYear().toString());
                    return result.join(".");
                }
        }
    };
    ObasHelper.ConvertStringToDate = function (str, format) {
        if (format === void 0) { format = DateFormat.Short; }
        if (str == null || str.length === 0) {
            return null;
        }
        switch (format) {
            case DateFormat.Short:
                var parts = str.split(".").map(function (value) {
                    return parseInt(value, 10);
                });
                if (parts.length < 3) {
                    throw new Error("Некорректный формат даты!\nОжидается формат:dd.mm.yyyy\nПередан:" + str);
                }
                return new Date(parts[2], parts[1], parts[0]);
            default:
                throw new Error("Not implemented");
        }
    };
    ObasHelper.FillWithCharacter = function (source, count, character, direction) {
        if (character === void 0) { character = "0"; }
        if (direction === void 0) { direction = FillCharactersDirection.First; }
        count -= source.toString().length;
        if (count > 0) {
            var addStr = new Array(count + 1).join(character);
            switch (direction) {
                case FillCharactersDirection.First:
                    return addStr + source;
                case FillCharactersDirection.Last:
                    return source + addStr;
                default:
                    return addStr + source;
            }
        }
        return source;
    };
    ObasHelper.GenerateExportTemplate = function (node) {
        return ObasHelper.IsGenerateToXsd ? node.ExportToXsd() : node.ExportToXml();
    };
    ObasHelper.GetMiddleDate = function () {
        return ObasHelper.ConvertToString(new Date(), DateFormat.Middle);
    };
    ObasHelper.GetLongDate = function () {
        return ObasHelper.ConvertToString(new Date(), DateFormat.Long);
    };
    ObasHelper.GetShortDate = function () {
        return ObasHelper.ConvertToString(new Date(), DateFormat.Short);
    };
    ObasHelper.GetFolderPath = function (folderName) {
        var folderPath = Client.GetCurrentDirectory() + folderName;
        if (!Client.IsDirectoryExists(folderPath)) {
            Client.CreateDirectory(folderPath);
        }
        return folderPath + "\\";
    };
    ObasHelper.GetFtExportFolder = function () {
        return this.GetFolderPath("Машиночитаемые данные");
    };
    ObasHelper.GetExcelExportFolder = function () {
        return this.GetFolderPath("Печатные формы");
    };
    ObasHelper.GetExcelData = function (value) {
        return value;
    };
    return ObasHelper;
}());
ObasHelper._useNodeAttrs = false;
ObasHelper._definedKeys = {
    DraftStatus: 1,
    ReadyStatus: 2
};
ObasHelper._monthNames = [
    { NomName: "январь", GenName: "января" },
    { NomName: "февраль", GenName: "февраля" },
    { NomName: "март", GenName: "марта" },
    { NomName: "апрель", GenName: "апреля" },
    { NomName: "май", GenName: "мая" },
    { NomName: "июнь", GenName: "июня" },
    { NomName: "июль", GenName: "июля" },
    { NomName: "август", GenName: "августа" },
    { NomName: "сентябрь", GenName: "сентября" },
    { NomName: "октябрь", GenName: "октября" },
    { NomName: "ноябрь", GenName: "ноября" },
    { NomName: "декабрь", GenName: "декабря" }
];
ObasHelper.IsGenerateToXsd = false;
ObasHelper.AllowCData = true;
